<?php

include('GoogleCache.php');

class GoogleCacheTest extends PHPUnit_Framework_TestCase
{  
  private $realSite          = 'http://www.bbc.co.uk/';
  private $crappyUrl         = 'http://8asdf<>< .7g5$&&*YTGDFNhm{~:546df';
  private $internalPage      = 'http://www.phpunit.de/manual/current/en/api.html#api.assert.assertRegExp';
  private $messedUpUserAgent = 'D"""SG>WERY$^£%:U*&JY@NFH~{^95465-itgfdfd#\'][,<>?rgfdy7i/.]';
  private $a404Url           = 'http://www.example.com/iosdyf89as7d6f8asdyfsdfsadfdfsaf.html';

  private $dateRegExp = '/(\d{1,2}\s[a-zA-Z]{3}\s\d{4}\s\d{2}:\d{2}:\d{2}.*?)/';

  public function testRealWebsiteCacheDate()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($this->realSite);

    // $date should not be false.
    $this->assertTrue(($date !== false));

    // $date should be a date
    $this->assertRegExp($this->dateRegExp, $date);

    // Result should be a date
    $this->assertRegExp($this->dateRegExp, $googleCache->getResult());

    // Raw result should be a string
    $this->assertTrue(is_string($googleCache->getRawResult()));
  }

  public function testInternalUrlCacheDate()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($this->internalPage);
    // $date should not be false.
    $this->assertTrue(($date !== false));

    // $date should be a date
    $this->assertRegExp($this->dateRegExp, $date);
  }

  public function testCrappyAddressCachedDate()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($this->crappyUrl);

    // $date should be false
    $this->assertFalse($date);
  }

  public function testUrlTooLong()
  {
    // Construct a long URL string.
    $tooLongUrl = '';
    while (strlen($tooLongUrl) < 2048) {
      $tooLongUrl .= implode('', range('a','Z'));
    }
    $tooLongUrl = 'http://' . $tooLongUrl;

    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($tooLongUrl);
    $this->assertFalse($date);
  }

  public function testRunTwoQueries()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($this->realSite);

    // $date should be a date
    $this->assertRegExp($this->dateRegExp, $date);

    $date = $googleCache->getLastCached($this->crappyUrl);

    // $date should be false
    $this->assertFalse($date);

    // Raw result string should be 0 chars long
    $this->assertTrue($googleCache->getRawResult() == '');
  }

  public function testMessedUpUserAgent()
  {
    $googleCache = new GoogleCache($this->messedUpUserAgent);
    $date = $googleCache->getLastCached($this->realSite);

    // $date should not be false.
    $this->assertTrue(($date !== false));

    // $date should be a date
    $this->assertRegExp($this->dateRegExp, $date);

    // Result should be a date
    $this->assertRegExp($this->dateRegExp, $googleCache->getResult());

    // Raw result should be a string
    $this->assertTrue(is_string($googleCache->getRawResult()));
  }

  public function testNoUrlString()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached('');

    // $date should be false
    $this->assertFalse($date);
  }

  public function testSpaceAsUrlString()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached(' ');

    // $date should be false
    $this->assertFalse($date);
  }

  public function testBooleanAsUrl()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached(false);

    // $date should be false
    $this->assertFalse($date);
  }

  public function testIntegerAsUrl()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached(12345);

    // $date should be false
    $this->assertFalse($date);
  }

  public function test404Url()
  {
    $googleCache = new GoogleCache();
    $date = $googleCache->getLastCached($this->a404Url);

    // $date should be false
    $this->assertFalse($date);
  }
}

